Security Policy
===============
Reporting a Vulnerability
-------------------------
**Do not report security issues on GitHub!**

Please report security issues by emailing Artur Barseghyan
<artur.barseghyan@gmail.com>.

Supported Versions
------------------
**Make sure to use the latest version.**

The two most recent ``faker-file`` release series receive security support.

For example, during the development cycle leading to the release
of ``faker-file`` 0.17.x, support will be provided for ``faker-file`` 0.16.x.

Upon the release of ``faker-file`` 0.18.x, security support for ``faker-file``
0.16.x will end.

.. code-block:: text

    ┌─────────────────┬────────────────┐
    │ Version         │ Supported      │
    ├─────────────────┼────────────────┤
    │ 0.17.x          │ Yes            │
    ├─────────────────┼────────────────┤
    │ 0.16.x          │ Yes            │
    ├─────────────────┼────────────────┤
    │ < 0.16          │ No             │
    └─────────────────┴────────────────┘
